# Select Host to change

- Update all hosts
- Recover deleted Hosts
- Add Host

MockedCsrfTokenNode
Action:
0 of 4 selected

| Name | WAN access | 1 Last Status | 2 Last update | IP (v4) | Mac | Create date
--- | --- | --- | --- | --- | --- | --- | ---
| double_name | unknown |  | Jan. 1, 2000, 1:04 a.m. | - | AB:CD:EF:12:00:04 | Jan. 1, 2000, 1:04 a.m.
| double_name | unknown |  | Jan. 1, 2000, 1:03 a.m. | - | AB:CD:EF:12:00:03 | Jan. 1, 2000, 1:03 a.m.
| unique_name2 | unknown |  | Jan. 1, 2000, 1:02 a.m. | - | AB:CD:EF:12:00:02 | Jan. 1, 2000, 1:02 a.m.
| unique_name1 | unknown |  | Jan. 1, 2000, 1:01 a.m. | - | AB:CD:EF:12:00:01 | Jan. 1, 2000, 1:01 a.m.

4 Hosts